@@ -1,11 +1,12 @@
 attach.all <- function(x, overwrite = NA, name = "attach.all"){
+  if(is.R()){
     rem <- names(x) %in% ls(.GlobalEnv)
     if(!any(rem)) overwrite <- FALSE
     rem <- names(x)[rem]
     if(is.na(overwrite)){
         question <- paste("The following objects in .GlobalEnv will mask\nobjects in the attached database:\n", 
-                          paste(rem, collapse=", "), 
-                          "\nRemove these objects from .GlobalEnv?", sep="")
+                        paste(rem, collapse=", "), 
+                        "\nRemove these objects from .GlobalEnv?", sep="")
         if(interactive()){
             if(.Platform$OS.type == "windows")
                 overwrite <- "YES" == winDialog(type = "yesno", question)
@@ -16,6 +17,9 @@ attach.all <- function(x, overwrite = NA, name = "attach.all"){
     }
     if(overwrite) remove(list=rem, envir=.GlobalEnv)
     attach(x, name=name)
+  } else {
+    attach.default(x, name = name)
+  }
 }
 
 attach.bugs <- function (x, overwrite = NA){
@@ -25,12 +29,24 @@ attach.bugs <- function (x, overwrite = NA){
     detach("bugs.sims")}
   x$sims.list$n.sims <- x$n.sims   # put n.sims into sims.list for convenience
   r2 <- attach.all(x$sims.list, overwrite = overwrite, name = "bugs.sims")
-  invisible (bugs.sims = r2)
+  if (is.R())
+    invisible (bugs.sims = r2)
+  else 
+    invisible (r2)
 }
 
-detach.all <- function(name = "attach.all")
+detach.all <- function(name = "attach.all"){
+  if (is.R()){
     do.call("detach", list(name=name))
+  } else {
+    do.call("detach", list(what=name))
+  }
+}
 
 detach.bugs <- function(){
+  if (is.R()){
     detach.all("bugs.sims")
+  } else {
+    invisible(detach.all("bugs.sims"))
+  }
 }
